import store from '@/store/index'
class websocketUtil {
  constructor(url, time) {
  /*
  url 是请求的后端的地址
  time 是心跳包的时间
  */
    this.is_open_socket = false // 避免重复连接
    this.url = url || process.env.VUE_APP_BASE_WS
    this.data = null
    // 心跳检测
    this.timeout = time || 5000 // 多少秒执行检测
    this.heartbeatInterval = null // 检测服务器端是否还活着
    this.reconnectTimeOut = null // 重连之后多久再次重连
    this.onMessage = Function
    try {
      return this.connectSocketInit()
    } catch (e) {
      console.log('catch')
      this.is_open_socket = false
      this.reconnect()
    }
  }

  // 进入这个页面的时候创建websocket连接【整个页面随时使用】
  connectSocketInit () {
    const token = store.getters.token
    if (!token) {
      console.log('无效链接')
      return false
    }
    this.socketTask = uni.connectSocket({
      url: `${this.url}?token=${token}`,
      success: () => {
        console.log('正准备建立websocket中...')
        // 返回实例
        return this.socketTask
      }
    })
    this.socketTask.onOpen((res) => {
      console.log('WebSocket连接正常！')
      clearTimeout(this.reconnectTimeOut)
      clearTimeout(this.heartbeatInterval)
      this.is_open_socket = true
      this.start()
      // 注：只有连接正常打开中 ，才能正常收到消息
      this.socketTask.onMessage((res) => {
        try {
          const data = JSON.parse(res.data)
          // 业务逻辑
          this.onMessage(data)
        } catch (error) {
          this.onMessage(res.data)
        }
      })
    })
    // 这里仅是事件监听【如果socket关闭了会执行】
    this.socketTask.onClose((res) => {
      if (res.code === 1000) {
        this.is_open_socket = true
      } else {
        this.is_open_socket = false
      }
      console.log('已经被关闭了', res)
      this.reconnect()
    })
  }

  // 发送消息
  send (value) {
    // 注：只有连接正常打开中 ，才能正常成功发送消息
    this.socketTask.send({
      data: value
    })
  }

  // 开启心跳检测
  start () {
    this.heartbeatInterval = setInterval(() => {
      this.data = { class: 'Index', type: 'heart' }
      this.send(JSON.stringify(this.data))
    }, this.timeout)
  }

  // 重新连接
  reconnect () {
    // 停止发送心跳
    clearInterval(this.heartbeatInterval)
    // 如果不是人为关闭的话，进行重连
    if (!this.is_open_socket) {
      this.reconnectTimeOut = setTimeout(() => {
        this.connectSocketInit()
      }, 3000)
    }
  }
}

module.exports = websocketUtil
